@@ -1,4 +1,3 @@
-print("DONWLOADED")
 import pkg_resources
 # if running in development there may not be a package
 try:
@@ -6,6 +5,8 @@ try:
 except pkg_resources.DistributionNotFound:
     __version__ = 'development'
 
+print()
+    
 from .pandas_printer import format_pandas
 from pyperclip import copy
 
