@@ -123,6 +123,10 @@ def format_pandas(obj):
 
     elif isinstance(obj, pd.Index):
         return format_index(obj)
+    
+def print_this(x):
+    print(x)
+    return True
         
         
 #
